hist package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hist.axis

Submodules
----------

hist.accumulators module
------------------------

.. automodule:: hist.accumulators
   :members:
   :undoc-members:
   :show-inheritance:

hist.axestuple module
---------------------

.. automodule:: hist.axestuple
   :members:
   :undoc-members:
   :show-inheritance:

hist.basehist module
--------------------

.. automodule:: hist.basehist
   :members:
   :undoc-members:
   :show-inheritance:

hist.classichist module
-----------------------

.. automodule:: hist.classichist
   :members:
   :undoc-members:
   :show-inheritance:

hist.hist module
----------------

.. automodule:: hist.hist
   :members:
   :undoc-members:
   :show-inheritance:

hist.intervals module
---------------------

.. automodule:: hist.intervals
   :members:
   :undoc-members:
   :show-inheritance:

hist.namedhist module
---------------------

.. automodule:: hist.namedhist
   :members:
   :undoc-members:
   :show-inheritance:

hist.numpy module
-----------------

.. automodule:: hist.numpy
   :members:
   :undoc-members:
   :show-inheritance:

hist.stack module
-------------------

.. automodule:: hist.stack
   :members:
   :undoc-members:
   :show-inheritance:

hist.storage module
-------------------

.. automodule:: hist.storage
   :members:
   :undoc-members:
   :show-inheritance:

hist.tag module
---------------

.. automodule:: hist.tag
   :members:
   :undoc-members:
   :show-inheritance:

hist.version module
-------------------

.. automodule:: hist.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hist
   :members:
   :undoc-members:
   :show-inheritance:
